{% load i18n %}

<div class="col-sm-6 col-md-4 col-lg-3 mb-4">
    <div class="card border-default">
        <div class="card-header text-bg-default">
            <div class="card-title mb-0">
                {{ timezone.panel_name }}
                <span class="float-end">
                    <i id="icon-{{ timezone.timezone.panel_id }}"></i>
                </span>
            </div>
        </div>

        <div class="card-body text-center timezone-panel">
            <span id="date-{{ timezone.timezone.panel_id }}" class="timezone-panel-section timezone-panel-section-date">({% translate "loading" %})</span>
            <span id="time-{{ timezone.timezone.panel_id }}" class="timezone-panel-section timezone-panel-section-time fw-bold">--:--:--</span>
            <span id="utc-offset-{{ timezone.timezone.panel_id }}" class="timezone-panel-section timezone-panel-section-utc-offset"></span>
        </div>
    </div>

    {% if timezone.timezone.timezone_name %}
        <script>
            aaTimezonesPanels = (typeof aaTimezonesPanels != 'undefined' && aaTimezonesPanels instanceof Array) ? aaTimezonesPanels : []

            aaTimezonesPanels.push({
                'timezoneName': '{{ timezone.timezone.timezone_name }}',
                'timezoneId': '{{ timezone.timezone.panel_id }}'
            });
        </script>
    {% endif %}
</div>
